==> libuhd-docs-4.8.0.0-7-x86_64.pkg.tar.zst: usr/share/doc/uhd/doxygen/html/dir_eaba5d3dd04ebc54ddc7f2a93ac27917.js <==
var dir_eaba5d3dd04ebc54ddc7f2a93ac27917 =
[
    [ "rf_control", "dir_c76e00dd28ac68b8174c78e4e3f23828.html", "dir_c76e00dd28ac68b8174c78e4e3f23828" ],
    [ "actions.hpp", "actions_8hpp.html", "actions_8hpp" ],
    [ "addsub_block_control.hpp", "addsub__block__control_8hpp.html", null ],
    [ "block_control.hpp", "block__control_8hpp.html", null ],
    [ "block_controller_factory_python.hpp", "block__controller__factory__python_8hpp.html", "block__controller__factory__python_8hpp" ],
    [ "block_id.hpp", "block__id_8hpp.html", "block__id_8hpp" ],
    [ "blockdef.hpp", "blockdef_8hpp.html", "blockdef_8hpp" ],
    [ "chdr_types.hpp", "chdr__types_8hpp.html", "chdr__types_8hpp" ],
    [ "constants.hpp", "constants_8hpp.html", "constants_8hpp" ],
    [ "ddc_block_control.hpp", "ddc__block__control_8hpp.html", null ],
    [ "defaults.hpp", "defaults_8hpp.html", "defaults_8hpp" ],
    [ "dirtifier.hpp", "dirtifier_8hpp.html", "dirtifier_8hpp" ],
    [ "dmafifo_block_control.hpp", "dmafifo__block__control_8hpp.html", null ],
    [ "duc_block_control.hpp", "duc__block__control_8hpp.html", null ],
    [ "fft_block_control.hpp", "fft__block__control_8hpp.html", "fft__block__control_8hpp" ],
    [ "filter_node.hpp", "filter__node_8hpp.html", "filter__node_8hpp" ],
    [ "fir_filter_block_control.hpp", "fir__filter__block__control_8hpp.html", null ],
    [ "fosphor_block_control.hpp", "fosphor__block__control_8hpp.html", "fosphor__block__control_8hpp" ],
    [ "graph_edge.hpp", "graph__edge_8hpp.html", "graph__edge_8hpp" ],
    [ "keep_one_in_n_block_control.hpp", "keep__one__in__n__block__control_8hpp.html", null ],
    [ "lc_block_control.hpp", "lc__block__control_8hpp.html", null ],
    [ "logpwr_block_control.hpp", "logpwr__block__control_8hpp.html", null ],
    [ "mb_controller.hpp", "mb__controller_8hpp.html", "mb__controller_8hpp" ],
    [ "mock_block.hpp", "mock__block_8hpp.html", "mock__block_8hpp" ],
    [ "moving_average_block_control.hpp", "moving__average__block__control_8hpp.html", "moving__average__block__control_8hpp" ],
    [ "multichan_register_iface.hpp", "multichan__register__iface_8hpp.html", "multichan__register__iface_8hpp" ],
    [ "noc_block_base.hpp", "noc__block__base_8hpp.html", "noc__block__base_8hpp" ],
    [ "noc_block_make_args.hpp", "noc__block__make__args_8hpp.html", "noc__block__make__args_8hpp" ],
    [ "node.hpp", "node_8hpp.html", "node_8hpp" ],
    [ "node.ipp", "node_8ipp.html", null ],
    [ "null_block_control.hpp", "null__block__control_8hpp.html", null ],
    [ "property.hpp", "property_8hpp.html", "property_8hpp" ],
    [ "property.ipp", "property_8ipp.html", null ],
    [ "radio_control.hpp", "radio__control_8hpp.html", null ],
    [ "register_iface.hpp", "register__iface_8hpp.html", "register__iface_8hpp" ],
    [ "register_iface_holder.hpp", "register__iface__holder_8hpp.html", "register__iface__holder_8hpp" ],
    [ "registry.hpp", "registry_8hpp.html", "registry_8hpp" ],
    [ "replay_block_control.hpp", "replay__block__control_8hpp.html", null ],
    [ "res_source_info.hpp", "res__source__info_8hpp.html", "res__source__info_8hpp" ],
    [ "rfnoc_types.hpp", "rfnoc__types_8hpp.html", "rfnoc__types_8hpp" ],
    [ "siggen_block_control.hpp", "siggen__block__control_8hpp.html", "siggen__block__control_8hpp" ],
    [ "split_stream_block_control.hpp", "split__stream__block__control_8hpp.html", null ],
    [ "switchboard_block_control.hpp", "switchboard__block__control_8hpp.html", null ],
    [ "traffic_counter.hpp", "traffic__counter_8hpp.html", "traffic__counter_8hpp" ],
    [ "vector_iir_block_control.hpp", "vector__iir__block__control_8hpp.html", null ],
    [ "window_block_control.hpp", "window__block__control_8hpp.html", null ]
];

==> libuhd-docs-4.9.0.1-4-x86_64.pkg.tar.zst: usr/share/doc/uhd/doxygen/html/dir_eaba5d3dd04ebc54ddc7f2a93ac27917.js <==
var dir_eaba5d3dd04ebc54ddc7f2a93ac27917 =
[
    [ "detail", "dir_255b71d5d3f7d1273b5fcad153d9c857.html", "dir_255b71d5d3f7d1273b5fcad153d9c857" ],
    [ "rf_control", "dir_c76e00dd28ac68b8174c78e4e3f23828.html", "dir_c76e00dd28ac68b8174c78e4e3f23828" ],
    [ "actions.hpp", "actions_8hpp.html", "actions_8hpp" ],
    [ "addsub_block_control.hpp", "addsub__block__control_8hpp.html", null ],
    [ "block_control.hpp", "block__control_8hpp.html", null ],
    [ "block_controller_factory_python.hpp", "block__controller__factory__python_8hpp.html", "block__controller__factory__python_8hpp" ],
    [ "block_id.hpp", "block__id_8hpp.html", "block__id_8hpp" ],
    [ "blockdef.hpp", "blockdef_8hpp.html", "blockdef_8hpp" ],
    [ "chdr_types.hpp", "chdr__types_8hpp.html", "chdr__types_8hpp" ],
    [ "constants.hpp", "constants_8hpp.html", "constants_8hpp" ],
    [ "ddc_block_control.hpp", "ddc__block__control_8hpp.html", null ],
    [ "defaults.hpp", "defaults_8hpp.html", "defaults_8hpp" ],
    [ "dirtifier.hpp", "dirtifier_8hpp.html", "dirtifier_8hpp" ],
    [ "dmafifo_block_control.hpp", "dmafifo__block__control_8hpp.html", null ],
    [ "duc_block_control.hpp", "duc__block__control_8hpp.html", null ],
    [ "fft_block_control.hpp", "fft__block__control_8hpp.html", "fft__block__control_8hpp" ],
    [ "filter_node.hpp", "filter__node_8hpp.html", "filter__node_8hpp" ],
    [ "fir_filter_block_control.hpp", "fir__filter__block__control_8hpp.html", null ],
    [ "fosphor_block_control.hpp", "fosphor__block__control_8hpp.html", "fosphor__block__control_8hpp" ],
    [ "graph_edge.hpp", "graph__edge_8hpp.html", "graph__edge_8hpp" ],
    [ "keep_one_in_n_block_control.hpp", "keep__one__in__n__block__control_8hpp.html", null ],
    [ "lc_block_control.hpp", "lc__block__control_8hpp.html", null ],
    [ "logpwr_block_control.hpp", "logpwr__block__control_8hpp.html", null ],
    [ "mb_controller.hpp", "mb__controller_8hpp.html", "mb__controller_8hpp" ],
    [ "mock_block.hpp", "mock__block_8hpp.html", "mock__block_8hpp" ],
    [ "mock_nodes.hpp", "mock__nodes_8hpp.html", "mock__nodes_8hpp" ],
    [ "moving_average_block_control.hpp", "moving__average__block__control_8hpp.html", "moving__average__block__control_8hpp" ],
    [ "multichan_register_iface.hpp", "multichan__register__iface_8hpp.html", "multichan__register__iface_8hpp" ],
    [ "noc_block_base.hpp", "noc__block__base_8hpp.html", "noc__block__base_8hpp" ],
    [ "noc_block_make_args.hpp", "noc__block__make__args_8hpp.html", "noc__block__make__args_8hpp" ],
    [ "node.hpp", "node_8hpp.html", "node_8hpp" ],
    [ "node.ipp", "node_8ipp.html", null ],
    [ "node_accessor.hpp", "node__accessor_8hpp.html", "node__accessor_8hpp" ],
    [ "null_block_control.hpp", "null__block__control_8hpp.html", null ],
    [ "property.hpp", "property_8hpp.html", "property_8hpp" ],
    [ "property.ipp", "property_8ipp.html", null ],
    [ "radio_control.hpp", "radio__control_8hpp.html", null ],
    [ "register_iface.hpp", "register__iface_8hpp.html", "register__iface_8hpp" ],
    [ "register_iface_holder.hpp", "register__iface__holder_8hpp.html", "register__iface__holder_8hpp" ],
    [ "registry.hpp", "registry_8hpp.html", "registry_8hpp" ],
    [ "replay_block_control.hpp", "replay__block__control_8hpp.html", null ],
    [ "res_source_info.hpp", "res__source__info_8hpp.html", "res__source__info_8hpp" ],
    [ "rfnoc_types.hpp", "rfnoc__types_8hpp.html", "rfnoc__types_8hpp" ],
    [ "siggen_block_control.hpp", "siggen__block__control_8hpp.html", "siggen__block__control_8hpp" ],
    [ "split_stream_block_control.hpp", "split__stream__block__control_8hpp.html", null ],
    [ "switchboard_block_control.hpp", "switchboard__block__control_8hpp.html", null ],
    [ "traffic_counter.hpp", "traffic__counter_8hpp.html", "traffic__counter_8hpp" ],
    [ "vector_iir_block_control.hpp", "vector__iir__block__control_8hpp.html", null ],
    [ "window_block_control.hpp", "window__block__control_8hpp.html", null ]
];
